@@ -1,11 +1,12 @@
-from properties_loader import Properties
+from properties_loader import PropertiesImpl
 from sqlalchemy import create_engine
 from sqlalchemy.orm import Session, sessionmaker
-
+from properties_loader.interfaces import Properties
 from postgresql_db.inmutables import _Groups, _Properties, _Config, _DDLOptions
 
-_db_properties: dict = Properties().__dict__.get(_Groups.BD_CORE)
-_default_row_for_page: int = 25
+_properties: Properties = PropertiesImpl().__dict__
+
+_db_properties: dict = _properties.get(_Groups.BD_CORE)
 
 _ddl_auto_options: list = [
     str(_DDLOptions.CREATE),
@@ -18,11 +19,9 @@ _config: dict = {
     str(_Config.NAME_SHCEMA_MODULE): _db_properties.get(_Properties.PATH_MODULE_SCHEMA)
 }
 
-
-
 _url_connection: str = _db_properties.get(_Properties.URL_CONNECTION)
 _engine = create_engine(_url_connection)
 
 # Factoria de sessiones
-StandartSession: Session = sessionmaker(_engine, autocommit=False)
+StandardSession: Session = sessionmaker(_engine, autocommit=False)
 AutoCommitSession: Session = sessionmaker(_engine, autocommit=True)
\ No newline at end of file
